@@ -26,4 +26,4 @@ class DriverPyCore(BaseParser):
         if params is None:
             params = {}
         params['token'] = os.environ['CORE_TOKEN']
-        return pycore.utils.request(os.environ['CORE_URL'], function, debug=self.debug)
\ No newline at end of file
+        return pycore.utils.request(os.environ['CORE_URL'], function, params, debug=self.debug)
\ No newline at end of file
